#!/usr/bin/env python
# encoding: utf-8

"""
Copyright (C) 2011  Julien Le Sech - www.idreammicro.com

This file is part of the MAX7219 library for Bus Pirate.

This library is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option)b any later
version.

This library is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for moredetails.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
"""

import argparse
import sys 

from max7219 import *

def main():
    """
    This program drives a MAX7219 using Bus Pirate in binary mode.
    """
    
    # Parse arguments.
    parser = argparse.ArgumentParser()
    parser.add_argument(
		"-p", "--port", dest = "port", default = "/dev/ttyUSB0",
		help = "Serial port to use.")
    parser.add_argument(
		"-b", "--baudrate", dest = "baudrate", default = "115200",
		help = "Baudrate")
    args = parser.parse_args()
    
    print "Serial port = " + args.port
    print "Baudrate = " + args.baudrate
    
	# Create MAX7219 object.
    device = Max7219(args.port, args.baudrate)
    
	# Initialize MAX7219.
    device.initialize()
    
	# Set scan limit.
    device.set_scan_limit(ScanLimit.Digit0To7)

	# Set intensity.
    device.set_intensity(Intensity.Level15)

	# Set decode mode.
    device.set_decode_mode(DecodeMode.AllDigits)

	# Write digits.
    device.write_digit(Digit.Digit0, Character.Zero)
    device.write_digit(Digit.Digit1, Character.One)
    device.write_digit(Digit.Digit2, Character.Two)
    device.write_digit(Digit.Digit3, Character.Three)
    device.write_digit(Digit.Digit4, Character.Four)
    device.write_digit(Digit.Digit5, Character.Five)
    device.write_digit(Digit.Digit6, Character.Six)
    device.write_digit(Digit.Digit7, Character.Seven)
    
    # Enable display.
    device.set_shutdown_mode(ShutdownMode.NormalOperation)

if __name__ == '__main__':
    main()
    
